@@ -317,10 +317,25 @@ class CrontabSchedule(models.Model):
 
     @property
     def human_readable(self):
+        try:
+            c = schedules.crontab(
+                minute=self.minute,
+                hour=self.hour,
+                day_of_week=self.day_of_week,
+                day_of_month=self.day_of_month,
+                month_of_year=self.month_of_year,
+            )
+            if c.day_of_week and set(c.day_of_week) == set(range(7)):
+                day_of_week = "*"
+            else:
+                day_of_week = cronexp(",".join(map(str, c.day_of_week)))
+        except ValueError:
+            day_of_week = cronexp(self.day_of_week)
+
         cron_expression = '{} {} {} {} {}'.format(
             cronexp(self.minute), cronexp(self.hour),
             cronexp(self.day_of_month), cronexp(self.month_of_year),
-            cronexp(self.day_of_week)
+            day_of_week
         )
         try:
             human_readable = get_description(cron_expression)
@@ -375,6 +390,11 @@ class CrontabSchedule(models.Model):
         except MultipleObjectsReturned:
             return cls.objects.filter(**spec).first()
 
+    def due_start_time(self, initial_start_time, tz):
+        start_time = initial_start_time.astimezone(tz)
+        start, ends_in, now = self.schedule.remaining_delta(start_time)
+        return start + ends_in
+
 
 class PeriodicTasks(models.Model):
     """Helper table for tracking updates to periodic tasks.
@@ -388,6 +408,10 @@ class PeriodicTasks(models.Model):
     ident = models.SmallIntegerField(default=1, primary_key=True, unique=True)
     last_update = models.DateTimeField(null=False)
 
+    class Meta:
+        verbose_name = _('periodic task track')
+        verbose_name_plural = _('periodic task tracks')
+
     @classmethod
     def changed(cls, instance, **kwargs):
         if not instance.no_changes:
@@ -644,3 +668,9 @@ class PeriodicTask(models.Model):
     @property
     def schedule(self):
         return self.scheduler.schedule
+
+    def due_start_time(self, tz):
+        if self.crontab:
+            return self.crontab.due_start_time(self.start_time, tz)
+        else:
+            return self.start_time
